@@ -18,7 +18,7 @@ try:
 except ImportError:
     from urllib import unquote
 
-__version__ = "0.6.0"
+__version__ = "0.6.1"
 
 def listdir(directory):
 
@@ -148,6 +148,7 @@ class Client(object):
 
         if self.webdav.cert_path:
             self.default_options['SSLCERT'] = self.webdav.cert_path
+            self.default_options['SSL_VERIFYHOST'] = 2
 
         if self.webdav.key_path:
             self.default_options['SSLKEY'] = self.webdav.key_path
@@ -276,7 +277,7 @@ class Client(object):
                 for resp in resps:
                     href = resp.findtext("{DAV:}href")
 
-                    if not href == path:
+                    if not path == unquote(href):
                         continue
                     else:
                         return True
